@@ -35,27 +35,10 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef HAVE_SEMIHOST_
-#include <semihost.h>
-#endif
 
 int
 main(void)
 {
 	printf("hello, world\n");
-
-#ifdef HAVE_SEMIHOST_
-	char	cmdline[128];
-	if (sys_semihost_get_cmdline(cmdline, sizeof(cmdline)) == 0) {
-		printf("Command line %s\n", cmdline);
-		FILE *f = fopen(cmdline, "r");
-		if (f) {
-			int c;
-			while ((c = getc(f)) != EOF)
-				putchar(c);
-		}
-	}
-#endif
-
 	exit(0);
 }
