@@ -431,7 +431,7 @@
 #endif
 
 /* XXX: should use `#if __STDC_VERSION__ < 199901'. */
-#if !__GNUC_PREREQ__(2, 7) && !defined(__INTEL_COMPILER)
+#if !__GNUC_PREREQ__(2, 7) && !defined(__INTEL_COMPILER) && !defined(__COMPCERT__)
 #define	__func__	NULL
 #endif
 
@@ -554,11 +554,38 @@
 #endif
 
 #if defined(__GNUC__) || defined(__INTEL_COMPILER)
-#ifndef __INTEL_COMPILER
+#if !defined(__INTEL_COMPILER) && defined(HAVE_ALIAS_ATTRIBUTE)
 #define	__strong_reference(sym,aliassym)	\
 	extern __typeof (sym) aliassym __attribute__ ((__alias__ (#sym)))
 #endif
 
+/*
+   Taken from glibc:
+   Add the compiler optimization to inhibit loop transformation to library
+   calls.  This is used to avoid recursive calls in memset and memmove
+   default implementations.
+*/
+#if defined(_HAVE_CC_INHIBIT_LOOP_TO_LIBCALL)
+# define __inhibit_loop_to_libcall \
+  __attribute__ ((__optimize__ ("-fno-tree-loop-distribute-patterns")))
+#elif defined(_HAVE_NO_BUILTIN_ATTRIBUTE)
+# define __inhibit_loop_to_libcall \
+    __attribute__((no_builtin))
+#else
+# define __inhibit_loop_to_libcall
+#endif
+
+/*
+ * Tell optimizer to not add new builtin calls when optimizing a
+ * function body.
+ */
+#if defined(_HAVE_NO_BUILTIN_ATTRIBUTE)
+# define __inhibit_new_builtin_calls \
+    __attribute__((no_builtin))
+#else
+#define __inhibit_new_builtin_calls
+#endif
+
 #ifdef __ELF__
 #ifdef __STDC__
 #define	__weak_reference(sym,alias)	\
@@ -769,6 +796,19 @@
 #define __nosanitizethread
 #endif
 
+/*
+ * fall-through case statement annotations
+ */
+#if __cplusplus >= 201703L || __STDC_VERSION__ > 201710L
+/* Standard C++17/C23 attribute */
+#define FALLTHROUGH [[fallthrough]]
+#elif __has_attribute(fallthrough)
+/* Non-standard but supported by at least gcc and clang */
+#define FALLTHROUGH __attribute__((fallthrough))
+#else
+#define FALLTHROUGH do { } while(0)
+#endif
+
 /* Guard variables and structure members by lock. */
 #define	__guarded_by(x)		__lock_annotate(guarded_by(x))
 #define	__pt_guarded_by(x)	__lock_annotate(pt_guarded_by(x))
