@@ -159,7 +159,7 @@ SUCH DAMAGE.
 #endif
 
 /* Configure small REENT structure for Xilinx MicroBlaze platforms */
-#if defined (__MICROBLAZE__)
+#if defined (__MICROBLAZE__) && !defined(__rtems__)
 #ifndef _REENT_SMALL
 #define _REENT_SMALL
 #endif
@@ -305,7 +305,7 @@ SUCH DAMAGE.
 #endif
 #endif
 
-#ifdef NEWLIB_TLS
+#ifdef PICOLIBC_TLS
 #define NEWLIB_THREAD_LOCAL __thread
 #else
 #define NEWLIB_THREAD_LOCAL
