@@ -143,6 +143,7 @@ No supporting OS subroutines are required.
  * SUCH DAMAGE.
  */
 
+#define _DEFAULT_SOURCE
 #include <newlib.h>
 #include <errno.h>
 #include <string.h>
@@ -283,6 +284,7 @@ setlocale (
        int category,
        const char *locale)
 {
+  (void) category;
 #ifndef _MB_CAPABLE
   if (locale)
     { 
@@ -428,7 +430,7 @@ setlocale (
 
 #ifdef _MB_CAPABLE
 static char *
-currentlocale ()
+currentlocale (void)
 {
   int i;
 
@@ -968,7 +970,7 @@ __get_locale_env (int category)
 }
 #endif /* _MB_CAPABLE */
 
-int
+size_t
 __locale_mb_cur_max (void)
 {
 #ifdef __HAVE_LOCALE_INFO__
