@@ -102,6 +102,7 @@ PORTABILITY
 <<newlocale>> is POSIX-1.2008.
 */
 
+#define _DEFAULT_SOURCE
 #include <newlib.h>
 #include <errno.h>
 #include <stdlib.h>
@@ -114,6 +115,9 @@ struct __locale_t *
 newlocale (int category_mask, const char *locale,
 	      struct __locale_t *base)
 {
+  (void) category_mask;
+  (void) locale;
+  (void) base;
 #ifndef _MB_CAPABLE
   return __get_C_locale ();
 #else /* _MB_CAPABLE */
