@@ -39,7 +39,7 @@ strcpy (char *to, const char *from)
 	char *pto = to;
 	unsigned int n = 0xFFFF;
 
-	asm volatile ("1:\n"
+	__asm__ volatile ("1:\n"
 	     "\tmove.b (%0)+,(%1)+\n"
 #if defined(__mcpu32__)
 	     "\tdbeq %2,1b\n"
