@@ -17,8 +17,6 @@ INDEX
 	__lock___env_recursive_mutex
 INDEX
 	__lock___tz_mutex
-INDEX
-	__lock___dd_hash_mutex
 INDEX
 	__lock___arc4random_mutex
 
@@ -52,7 +50,6 @@ SYNOPSIS
 	struct __lock __lock___malloc_recursive_mutex;
 	struct __lock __lock___env_recursive_mutex;
 	struct __lock __lock___tz_mutex;
-	struct __lock __lock___dd_hash_mutex;
 	struct __lock __lock___arc4random_mutex;
 
 	void __retarget_lock_init (_LOCK_T * <[lock_ptr]>);
@@ -93,66 +90,68 @@ struct __lock {
   char unused;
 };
 
-struct __lock __lock___sinit_recursive_mutex;
-struct __lock __lock___sfp_recursive_mutex;
-struct __lock __lock___atexit_recursive_mutex;
-struct __lock __lock___at_quick_exit_mutex;
-struct __lock __lock___malloc_recursive_mutex;
-struct __lock __lock___env_recursive_mutex;
-struct __lock __lock___tz_mutex;
-struct __lock __lock___dd_hash_mutex;
-struct __lock __lock___arc4random_mutex;
+struct __lock __lock___libc_recursive_mutex;
 
 void
 __retarget_lock_init (_LOCK_T *lock)
 {
+  (void) lock;
 }
 
 void
 __retarget_lock_init_recursive(_LOCK_T *lock)
 {
+  (void) lock;
 }
 
 void
 __retarget_lock_close(_LOCK_T lock)
 {
+  (void) lock;
 }
 
 void
 __retarget_lock_close_recursive(_LOCK_T lock)
 {
+  (void) lock;
 }
 
 void
 __retarget_lock_acquire (_LOCK_T lock)
 {
+  (void) lock;
 }
 
 void
 __retarget_lock_acquire_recursive (_LOCK_T lock)
 {
+  (void) lock;
 }
 
 int
 __retarget_lock_try_acquire(_LOCK_T lock)
 {
+  (void) lock;
   return 1;
 }
 
 int
 __retarget_lock_try_acquire_recursive(_LOCK_T lock)
 {
+  (void) lock;
   return 1;
 }
 
 void
 __retarget_lock_release (_LOCK_T lock)
 {
+  (void) lock;
 }
 
 void
 __retarget_lock_release_recursive (_LOCK_T lock)
 {
+  (void) lock;
 }
 
 #endif /* !defined(__SINGLE_THREAD__) */
