@@ -135,12 +135,11 @@ static char *pchar(int ch);
  ==	size_t nmatch, regmatch_t pmatch[], int eflags);
  */
 static int			/* 0 success, REG_NOMATCH failure */
-matcher(g, string, nmatch, pmatch, eflags)
-struct re_guts *g;
-char *string;
-size_t nmatch;
-regmatch_t pmatch[];
-int eflags;
+matcher(struct re_guts *g,
+        char *string,
+        size_t nmatch,
+        regmatch_t pmatch[],
+        int eflags)
 {
 	char *endp;
 	size_t i;
@@ -346,12 +345,11 @@ int eflags;
  ==	char *stop, sopno startst, sopno stopst);
  */
 static char *			/* == stop (success) always */
-dissect(m, start, stop, startst, stopst)
-struct match *m;
-char *start;
-char *stop;
-sopno startst;
-sopno stopst;
+dissect(struct match *m,
+        char *start,
+        char *stop,
+        sopno startst,
+        sopno stopst)
 {
 	int i;
 	sopno ss;		/* start sop of current subRE */
@@ -539,13 +537,12 @@ sopno stopst;
  ==	char *stop, sopno startst, sopno stopst, sopno lev);
  */
 static char *			/* == stop (success) or NULL (failure) */
-backref(m, start, stop, startst, stopst, lev)
-struct match *m;
-char *start;
-char *stop;
-sopno startst;
-sopno stopst;
-sopno lev;			/* PLUS nesting level */
+backref(struct match *m,
+        char *start,
+        char *stop,
+        sopno startst,
+        sopno stopst,
+        sopno lev)		/* PLUS nesting level */
 {
 	int i;
 	sopno ss;		/* start sop of current subRE */
@@ -744,12 +741,11 @@ sopno lev;			/* PLUS nesting level */
  ==	char *stop, sopno startst, sopno stopst);
  */
 static char *			/* where tentative match ended, or NULL */
-fast(m, start, stop, startst, stopst)
-struct match *m;
-char *start;
-char *stop;
-sopno startst;
-sopno stopst;
+fast(struct match *m,
+     char *start,
+     char *stop,
+     sopno startst,
+     sopno stopst)
 {
 	states st = m->st;
 	states fresh = m->fresh;
@@ -835,12 +831,11 @@ sopno stopst;
  ==	char *stop, sopno startst, sopno stopst);
  */
 static char *			/* where it ended */
-slow(m, start, stop, startst, stopst)
-struct match *m;
-char *start;
-char *stop;
-sopno startst;
-sopno stopst;
+slow(struct match *m,
+     char *start,
+     char *stop,
+     sopno startst,
+     sopno stopst)
 {
 	states st = m->st;
 	states empty = m->empty;
@@ -931,13 +926,12 @@ sopno stopst;
  == #define	NNONCHAR	(CODEMAX-CHAR_MAX)
  */
 static states
-step(g, start, stop, bef, ch, aft)
-struct re_guts *g;
-sopno start;			/* start state within strip */
-sopno stop;			/* state after stop state within strip */
-states bef;			/* states reachable before */
-int ch;				/* character or NONCHAR code */
-states aft;			/* states already known reachable after */
+step(struct re_guts *g,
+     sopno start,		/* start state within strip */
+     sopno stop,		/* state after stop state within strip */
+     states bef,		/* states reachable before */
+     int ch,			/* character or NONCHAR code */
+     states aft)		/* states already known reachable after */
 {
 	cset *cs;
 	sop s;
@@ -1053,12 +1047,11 @@ states aft;			/* states already known reachable after */
  == #endif
  */
 static void
-print(m, caption, st, ch, d)
-struct match *m;
-char *caption;
-states st;
-int ch;
-FILE *d;
+print(struct match *m,
+      char *caption,
+      states st,
+      int ch,
+      FILE *d)
 {
 	struct re_guts *g = m->g;
 	int i;
@@ -1086,13 +1079,12 @@ FILE *d;
  == #endif
  */
 static void
-at(m, title, start, stop, startst, stopst)
-struct match *m;
-char *title;
-char *start;
-char *stop;
-sopno startst;
-sopno stopst;
+at(struct match *m,
+   char *title,
+   char *start,
+   char *stop,
+   sopno startst,
+   sopno stopst)
 {
 	if (!(m->eflags&REG_TRACE))
 		return;
@@ -1116,8 +1108,7 @@ sopno stopst;
  * the non-debug compilation anyway, so it doesn't matter much.
  */
 static char *			/* -> representation */
-pchar(ch)
-int ch;
+pchar(int ch)
 {
 	static char pbuf[10];
 
