@@ -277,8 +277,7 @@ error0:
 }
 
 static int
-hash_close(dbp)
-	DB *dbp;
+hash_close(DB *dbp)
 {
 	HTAB *hashp;
 	int retval;
@@ -293,8 +292,7 @@ hash_close(dbp)
 }
 
 static int
-hash_fd(dbp)
-	const DB *dbp;
+hash_fd(const DB *dbp)
 {
 	HTAB *hashp;
 
@@ -311,10 +309,9 @@ hash_fd(dbp)
 
 /************************** LOCAL CREATION ROUTINES **********************/
 static HTAB *
-init_hash(hashp, file, info)
-	HTAB *hashp;
-	const char *file;
-	const HASHINFO *info;
+init_hash(HTAB *hashp,
+          const char *file,
+          const HASHINFO *info)
 {
 #ifdef __USE_INTERNAL_STAT64
         struct stat64 statbuf;
@@ -386,9 +383,7 @@ init_hash(hashp, file, info)
  * Returns 0 on No Error
  */
 static int
-init_htab(hashp, nelem)
-	HTAB *hashp;
-	int nelem;
+init_htab(HTAB *hashp, int nelem)
 {
 	int nbuckets, nsegs;
 	int l2;
@@ -432,8 +427,7 @@ init_htab(hashp, nelem)
  * structure, freeing all allocated space.
  */
 static int
-hdestroy(hashp)
-	HTAB *hashp;
+hdestroy(HTAB *hashp)
 {
 	int i, save_errno;
 
@@ -492,9 +486,7 @@ hdestroy(hashp)
  *	-1 ERROR
  */
 static int
-hash_sync(dbp, flags)
-	const DB *dbp;
-	u_int flags;
+hash_sync(const DB *dbp, u_int flags)
 {
 	HTAB *hashp;
 
@@ -521,8 +513,7 @@ hash_sync(dbp, flags)
  *	-1 indicates that errno should be set
  */
 static int
-flush_meta(hashp)
-	HTAB *hashp;
+flush_meta(HTAB *hashp)
 {
 	HASHHDR *whdrp;
 #if (BYTE_ORDER == LITTLE_ENDIAN)
@@ -569,11 +560,10 @@ flush_meta(hashp)
  *	-1 to indicate an internal ERROR (i.e. out of memory, etc)
  */
 static int
-hash_get(dbp, key, data, flag)
-	const DB *dbp;
-	const DBT *key;
-	DBT *data;
-	u_int flag;
+hash_get(const DB *dbp,
+         const DBT *key,
+         DBT *data,
+         u_int flag)
 {
 	HTAB *hashp;
 
@@ -586,11 +576,10 @@ hash_get(dbp, key, data, flag)
 }
 
 static int
-hash_put(dbp, key, data, flag)
-	const DB *dbp;
-	DBT *key;
-	const DBT *data;
-	u_int flag;
+hash_put(const DB *dbp,
+         DBT *key,
+         const DBT *data,
+         u_int flag)
 {
 	HTAB *hashp;
 
@@ -609,10 +598,9 @@ hash_put(dbp, key, data, flag)
 }
 
 static int
-hash_delete(dbp, key, flag)
-	const DB *dbp;
-	const DBT *key;
-	u_int flag;		/* Ignored */
+hash_delete(const DB *dbp,
+            const DBT *key,
+            u_int flag)    /* Ignored */
 {
 	HTAB *hashp;
 
@@ -632,10 +620,10 @@ hash_delete(dbp, key, flag)
  * Assume that hashp has been set in wrapper routine.
  */
 static int
-hash_access(hashp, action, key, val)
-	HTAB *hashp;
-	ACTION action;
-	DBT *key, *val;
+hash_access(HTAB *hashp,
+            ACTION action,
+            DBT *key,
+            DBT *val)
 {
 	BUFHEAD *rbufp;
 	BUFHEAD *bufp, *save_bufp;
@@ -761,10 +749,10 @@ found:
 }
 
 static int
-hash_seq(dbp, key, data, flag)
-	const DB *dbp;
-	DBT *key, *data;
-	u_int flag;
+hash_seq(const DB *dbp,
+         DBT *key,
+         DBT *data,
+         u_int flag)
 {
 	int32_t bucket;
 	BUFHEAD *bufp;
@@ -851,8 +839,7 @@ hash_seq(dbp, key, data, flag)
  *	-1 ==> Error
  */
 extern int
-__expand_table(hashp)
-	HTAB *hashp;
+__expand_table(HTAB *hashp)
 {
 	int32_t old_bucket, new_bucket;
 	int dirsize, new_segnum, spare_ndx;
@@ -906,9 +893,7 @@ __expand_table(hashp)
  * fails, then this routine can go away.
  */
 static void *
-hash_realloc(p_ptr, oldsize, newsize)
-	SEGMENT **p_ptr;
-	int oldsize, newsize;
+hash_realloc(SEGMENT **p_ptr, int oldsize, int newsize)
 {
 	void *p;
 
@@ -922,10 +907,9 @@ hash_realloc(p_ptr, oldsize, newsize)
 }
 
 extern __uint32_t
-__call_hash(hashp, k, len)
-	HTAB *hashp;
-	char *k;
-	int len;
+__call_hash(HTAB *hashp,
+            char *k,
+            int len)
 {
 	int32_t n, bucket;
 
@@ -942,9 +926,7 @@ __call_hash(hashp, k, len)
  * Returns 0 on success
  */
 static int
-alloc_segs(hashp, nsegs)
-	HTAB *hashp;
-	int nsegs;
+alloc_segs(HTAB *hashp, int nsegs)
 {
 	int i;
 	SEGMENT store;
@@ -976,8 +958,7 @@ alloc_segs(hashp, nsegs)
  * Hashp->hdr needs to be byteswapped.
  */
 static void
-swap_header_copy(srcp, destp)
-	HASHHDR *srcp, *destp;
+swap_header_copy(HASHHDR *srcp, HASHHDR *destp)
 {
 	int i;
 
@@ -1005,8 +986,7 @@ swap_header_copy(srcp, destp)
 }
 
 static void
-swap_header(hashp)
-	HTAB *hashp;
+swap_header(HTAB *hashp)
 {
 	HASHHDR *hdrp;
 	int i;
