@@ -92,9 +92,7 @@ static int	 ugly_split
  * stuff on.
  */
 static void
-putpair(p, key, val)
-	char *p;
-	const DBT *key, *val;
+putpair(char *p, const DBT *key, const DBT *val)
 {
 	__uint16_t *bp, n, off;
 
@@ -124,10 +122,9 @@ putpair(p, key, val)
  *	-1 error
  */
 extern int
-__delpair(hashp, bufp, ndx)
-	HTAB *hashp;
-	BUFHEAD *bufp;
-	int ndx;
+__delpair(HTAB *hashp,
+          BUFHEAD *bufp,
+          int ndx)
 {
 	__uint16_t *bp, newoff;
 	int n;
@@ -177,9 +174,9 @@ __delpair(hashp, bufp, ndx)
  *	-1 ==> Error
  */
 extern int
-__split_page(hashp, obucket, nbucket)
-	HTAB *hashp;
-	__uint32_t obucket, nbucket;
+__split_page(HTAB *hashp,
+             __uint32_t obucket,
+             __uint32_t nbucket)
 {
 	BUFHEAD *new_bufp, *old_bufp;
 	__uint16_t *ino;
@@ -273,12 +270,12 @@ __split_page(hashp, obucket, nbucket)
  *	-1 ==> failure
  */
 static int
-ugly_split(hashp, obucket, old_bufp, new_bufp, copyto, moved)
-	HTAB *hashp;
-	__uint32_t obucket;	/* Same as __split_page. */
-	BUFHEAD *old_bufp, *new_bufp;
-	int copyto;	/* First byte on page which contains key/data values. */
-	int moved;		/* Number of pairs moved to new page. */
+ugly_split(HTAB *hashp,
+           __uint32_t obucket,	/* Same as __split_page. */
+           BUFHEAD *old_bufp,
+           BUFHEAD *new_bufp,
+           int copyto,  	/* First byte on page which contains key/data values. */
+           int moved)		/* Number of pairs moved to new page. */
 {
 	BUFHEAD *bufp;		/* Buffer header for ino */
 	__uint16_t *ino;		/* Page keys come off of */
@@ -394,10 +391,10 @@ ugly_split(hashp, obucket, old_bufp, new_bufp, copyto, moved)
  *	1 ==> failure
  */
 extern int
-__addel(hashp, bufp, key, val)
-	HTAB *hashp;
-	BUFHEAD *bufp;
-	const DBT *key, *val;
+__addel(HTAB *hashp,
+	BUFHEAD *bufp,
+	const DBT *key,
+        const DBT *val)
 {
 	__uint16_t *bp, *sop;
 	int do_expand;
@@ -461,9 +458,7 @@ __addel(hashp, bufp, key, val)
  *	NULL on error
  */
 extern BUFHEAD *
-__add_ovflpage(hashp, bufp)
-	HTAB *hashp;
-	BUFHEAD *bufp;
+__add_ovflpage(HTAB *hashp, BUFHEAD *bufp)
 {
 	__uint16_t *sp;
 	__uint16_t ndx, ovfl_num;
@@ -514,11 +509,12 @@ __add_ovflpage(hashp, bufp)
  *	-1 indicates FAILURE
  */
 extern int
-__get_page(hashp, p, bucket, is_bucket, is_disk, is_bitmap)
-	HTAB *hashp;
-	char *p;
-	__uint32_t bucket;
-	int is_bucket, is_disk, is_bitmap;
+__get_page(HTAB *hashp,
+           char *p,
+           __uint32_t bucket,
+           int is_bucket,
+           int is_disk,
+           int is_bitmap)
 {
 	int fd, page, size;
 	int rsize;
@@ -574,11 +570,11 @@ __get_page(hashp, p, bucket, is_bucket, is_disk, is_bitmap)
  *	-1 ==>failure
  */
 extern int
-__put_page(hashp, p, bucket, is_bucket, is_bitmap)
-	HTAB *hashp;
-	char *p;
-	__uint32_t bucket;
-	int is_bucket, is_bitmap;
+__put_page(HTAB *hashp,
+           char *p,
+           __uint32_t bucket,
+           int is_bucket,
+           int is_bitmap)
 {
 	int fd, page, size;
 	int wsize;
@@ -623,9 +619,10 @@ __put_page(hashp, p, bucket, is_bucket, is_bitmap)
  * once they are read in.
  */
 extern int
-__ibitmap(hashp, pnum, nbits, ndx)
-	HTAB *hashp;
-	int pnum, nbits, ndx;
+__ibitmap(HTAB *hashp,
+          int pnum,
+          int nbits,
+          int ndx)
 {
 	__uint32_t *ip;
 	int clearbytes, clearints;
@@ -646,8 +643,7 @@ __ibitmap(hashp, pnum, nbits, ndx)
 }
 
 static __uint32_t
-first_free(map)
-	__uint32_t map;
+first_free(__uint32_t map)
 {
 	__uint32_t i, mask;
 
@@ -661,8 +657,7 @@ first_free(map)
 }
 
 static __uint16_t
-overflow_page(hashp)
-	HTAB *hashp;
+overflow_page(HTAB *hashp)
 {
 	__uint32_t *freep = NULL;
 	int max_free, offset, splitnum;
@@ -809,9 +804,7 @@ found:
  * Mark this overflow page as free.
  */
 extern void
-__free_ovflpage(hashp, obufp)
-	HTAB *hashp;
-	BUFHEAD *obufp;
+__free_ovflpage(HTAB *hashp, BUFHEAD *obufp)
 {
 	__uint16_t addr;
 	__uint32_t *freep;
@@ -855,8 +848,7 @@ __free_ovflpage(hashp, obufp)
  *	-1 failure
  */
 static int
-open_temp(hashp)
-	HTAB *hashp;
+open_temp(HTAB *hashp)
 {
 	sigset_t set, oset;
 	static char namestr[] = "_hashXXXXXX";
@@ -879,9 +871,9 @@ open_temp(hashp)
  * an overflow pair, so we need to shift things.
  */
 static void
-squeeze_key(sp, key, val)
-	__uint16_t *sp;
-	const DBT *key, *val;
+squeeze_key(__uint16_t *sp,
+            const DBT *key,
+            const DBT *val)
 {
 	char *p;
 	__uint16_t free_space, n, off, pageno;
@@ -906,9 +898,7 @@ squeeze_key(sp, key, val)
 }
 
 static __uint32_t *
-fetch_bitmap(hashp, ndx)
-	HTAB *hashp;
-	int ndx;
+fetch_bitmap(HTAB *hashp, int ndx)
 {
 	if (ndx >= hashp->nmaps)
 		return (NULL);
