@@ -567,6 +567,7 @@ Supporting OS subroutines required: <<close>>, <<fstat>>, <<isatty>>,
 <<lseek>>, <<read>>, <<sbrk>>, <<write>>.
 */
 
+#define _DEFAULT_SOURCE
 #include <_ansi.h>
 #include <stdio.h>
 #include <stdarg.h>
@@ -601,6 +602,8 @@ _siprintf_r (struct _reent *, char *, const char *, ...)
 
 #ifndef _REENT_ONLY
 
+#undef sprintf
+
 int
 sprintf (char *__restrict str,
        const char *__restrict fmt, ...)
