@@ -74,6 +74,7 @@ These are GNU extensions.
 Supporting OS subroutines required:
 */
 
+#define _DEFAULT_SOURCE
 #include <_ansi.h>
 #include <newlib.h>
 #include <ctype.h>
@@ -181,7 +182,7 @@ static void * get_arg (int, va_list *, int *, void **);
 
 /*
  * The following are used in numeric conversions only:
- * SIGNOK, NDIGITS, DPTOK, and EXPOK are for floating point;
+ * SIGNOK, NDIGITS, DPTOK, EXPOK and HEXFLT are for floating point;
  * SIGNOK, NDIGITS, PFXOK, and NZDIGITS are for integral.
  */
 
@@ -190,6 +191,7 @@ static void * get_arg (int, va_list *, int *, void **);
 
 #define	DPTOK		0x200	/* (float) decimal point is still legal */
 #define	EXPOK		0x400	/* (float) exponent (e+3, etc) still legal */
+#define	HEXFLT		0x800	/* (float) hex prefix found, expect hex float */
 
 #define	PFXOK		0x200	/* 0x prefix is (still) legal */
 #define	NZDIGITS	0x400	/* no zero digits detected */
@@ -323,6 +325,7 @@ __ssrefill_r (struct _reent * ptr,
    * Our only hope of further input is the ungetc buffer.
    * If there is anything in that buffer to read, return.
    */
+  (void) ptr;
   if (HASUB (fp))
     {
       FREEUB (ptr, fp);
@@ -358,7 +361,7 @@ _sfread_r (struct _reent * ptr,
   total = resid;
   p = buf;
 
-  while (resid > (r = fp->_r))
+  while (resid > (size_t) (r = fp->_r))
     {
       (void) memcpy ((void *) p, (void *) fp->_p, (size_t) r);
       fp->_p += r;
@@ -388,6 +391,7 @@ __wctob (struct _reent *rptr, wint_t wc)
   mbstate_t mbs;
   unsigned char pmb[MB_LEN_MAX];
 
+  (void) rptr;
   if (wc == WEOF)
     return EOF;
   memset (&mbs, '\0', sizeof (mbs));
@@ -441,13 +445,13 @@ __SVFSCANF_R (struct _reent *rptr,
     void ***m_arr;		/* Array of pointer args to 'm' conversion */
     uint16_t m_siz;		/* Number of slots in m_arr */
     uint16_t m_cnt;		/* Number of valid entries in m_arr */
-  } *m_ptr = NULL;
+  } *m_ptr = NULL, m_store;
   #define init_m_ptr()							\
     do									\
       {									\
 	if (!m_ptr)							\
 	  {								\
-	    m_ptr = (struct m_ptrs *) alloca (sizeof *m_ptr);		\
+	    m_ptr = &m_store;		                                \
 	    m_ptr->m_arr = NULL;					\
 	    m_ptr->m_siz = 0;						\
 	    m_ptr->m_cnt = 0;						\
@@ -499,8 +503,8 @@ __SVFSCANF_R (struct _reent *rptr,
       size_t _nw = (_w);						\
       ptrdiff_t _dif = _p - _p0;					\
       if (_p_p &&							\
-	  ((sizeof (_type) == 2 && _dif >= _nw - 1)			\
-	   || _dif >= _nw))						\
+	  ((sizeof (_type) == 2 && (size_t) _dif >= _nw - 1)             \
+	   || (size_t) _dif >= _nw))                                    \
 	{								\
 	  _p0 = (_type *) realloc (_p0, (_nw << 1) * sizeof (_type));			\
 	  if (!_p0)							\
@@ -786,7 +790,7 @@ __SVFSCANF_R (struct _reent *rptr,
 
 	case 'D':		/* compat */
 	  flags |= LONG;
-	  /* FALLTHROUGH */
+	  FALLTHROUGH;
 	case 'd':
 	  c = CT_INT;
 	  ccfn = (u_long (*)CCFN_PARAMS)strtol;
@@ -801,7 +805,7 @@ __SVFSCANF_R (struct _reent *rptr,
 
 	case 'O':		/* compat */
 	  flags |= LONG;
-	  /* FALLTHROUGH */
+	  FALLTHROUGH;
 	case 'o':
 	  c = CT_INT;
 	  ccfn = strtoul;
@@ -840,7 +844,7 @@ __SVFSCANF_R (struct _reent *rptr,
 #ifdef _WANT_IO_C99_FORMATS
 	case 'S':
 	  flags |= LONG;
-	  /* FALLTHROUGH */
+          FALLTHROUGH;
 #endif
 
 	case 's':
@@ -856,7 +860,7 @@ __SVFSCANF_R (struct _reent *rptr,
 #ifdef _WANT_IO_C99_FORMATS
 	case 'C':
 	  flags |= LONG;
-	  /* FALLTHROUGH */
+          FALLTHROUGH;
 #endif
 
 	case 'c':
@@ -965,26 +969,26 @@ __SVFSCANF_R (struct _reent *rptr,
 #endif
               else
                 wcp = GET_ARG (N, ap, wchar_t *);
-              n = 0;
+              size_t s = 0;
               while (width != 0)
                 {
-                  if (n == MB_CUR_MAX)
+                  if (s == MB_CUR_MAX)
                     goto input_failure;
-                  buf[n++] = *fp->_p;
+                  buf[s++] = *fp->_p;
                   fp->_r -= 1;
                   fp->_p += 1;
 		  /* Got a high surrogate, allow low surrogate to slip
 		     through */
 		  if (mbslen != 3 || state.__count != 4)
 		    memset (&state, 0, sizeof (mbstate_t));
-                  if ((mbslen = mbrtowc (wcp, buf, n, &state))
+                  if ((mbslen = mbrtowc (wcp, buf, s, &state))
                                                          == (size_t)-1)
                     goto input_failure; /* Invalid sequence */
                   if (mbslen == 0 && !(flags & SUPPRESS))
                     *wcp = L'\0';
                   if (mbslen != (size_t)-2) /* Incomplete sequence */
                     {
-                      nread += n;
+                      nread += s;
 		      /* Handle high surrogate */
 		      if (mbslen != 3 || state.__count != 4)
 			width -= 1;
@@ -996,11 +1000,11 @@ __SVFSCANF_R (struct _reent *rptr,
 #endif
 			  wcp++;
 			}
-                      n = 0;
+                      s = 0;
                     }
                   if (BufferEmpty)
 	            {
-                      if (n != 0)
+                      if (s != 0)
                         goto input_failure;
                       break;
                     }
@@ -1083,18 +1087,18 @@ __SVFSCANF_R (struct _reent *rptr,
 #endif
               else
 		wcp = GET_ARG (N, ap, wchar_t *);
-              n = 0;
+              size_t s = 0;
               while (width != 0) {
-                  if (n == MB_CUR_MAX)
+                  if (s == MB_CUR_MAX)
                     goto input_failure;
-                  buf[n++] = *fp->_p;
+                  buf[s++] = *fp->_p;
                   fp->_r -= 1;
                   fp->_p += 1;
 		  /* Got a high surrogate, allow low surrogate to slip
 		     through */
 		  if (mbslen != 3 || state.__count != 4)
 		    memset (&state, 0, sizeof (mbstate_t));
-                  if ((mbslen = mbrtowc (wcp, buf, n, &state))
+                  if ((mbslen = mbrtowc (wcp, buf, s, &state))
                                                         == (size_t)-1)
                     goto input_failure;
                   if (mbslen == 0)
@@ -1103,11 +1107,11 @@ __SVFSCANF_R (struct _reent *rptr,
                     {
                       if (!ccltab[__wctob (rptr, *wcp)])
                         {
-                          while (n != 0)
-                            _ungetc_r (rptr, (unsigned char) buf[--n], fp);
+                          while (s != 0)
+                            _ungetc_r (rptr, (unsigned char) buf[--s], fp);
                           break;
                         }
-                      nread += n;
+                      nread += s;
 		      /* Handle high surrogate */
 		      if (mbslen != 3 || state.__count != 4)
 			width -= 1;
@@ -1119,11 +1123,11 @@ __SVFSCANF_R (struct _reent *rptr,
 						   wcp_siz);
 #endif
 			}
-                      n = 0;
+                      s = 0;
                     }
                   if (BufferEmpty)
                     {
-                      if (n != 0)
+                      if (s != 0)
                         goto input_failure;
                       break;
                     }
@@ -1219,19 +1223,19 @@ __SVFSCANF_R (struct _reent *rptr,
 #endif
               else
 		wcp = GET_ARG (N, ap, wchar_t *);
-              n = 0;
+              size_t s = 0;
               while (!isspace (*fp->_p) && width != 0)
                 {
-                  if (n == MB_CUR_MAX)
+                  if (s == MB_CUR_MAX)
                     goto input_failure;
-                  buf[n++] = *fp->_p;
+                  buf[s++] = *fp->_p;
                   fp->_r -= 1;
                   fp->_p += 1;
 		  /* Got a high surrogate, allow low surrogate to slip
 		     through */
 		  if (mbslen != 3 || state.__count != 4)
 		    memset (&state, 0, sizeof (mbstate_t));
-                  if ((mbslen = mbrtowc (wcp, buf, n, &state))
+                  if ((mbslen = mbrtowc (wcp, buf, s, &state))
                                                         == (size_t)-1)
                     goto input_failure;
                   if (mbslen == 0)
@@ -1240,11 +1244,11 @@ __SVFSCANF_R (struct _reent *rptr,
                     {
                       if (iswspace(*wcp))
                         {
-                          while (n != 0)
-                            _ungetc_r (rptr, (unsigned char) buf[--n], fp);
+                          while (s != 0)
+                            _ungetc_r (rptr, (unsigned char) buf[--s], fp);
                           break;
                         }
-                      nread += n;
+                      nread += s;
 		      /* Handle high surrogate */
 		      if (mbslen != 3 || state.__count != 4)
 			width -= 1;
@@ -1256,11 +1260,11 @@ __SVFSCANF_R (struct _reent *rptr,
 						   wcp_siz);
 #endif
 			}
-                      n = 0;
+                      s = 0;
                     }
                   if (BufferEmpty)
                     {
-                      if (n != 0)
+                      if (s != 0)
                         goto input_failure;
                       break;
                     }
@@ -1604,6 +1608,38 @@ __SVFSCANF_R (struct _reent *rptr,
 		    }
 		  break;
 
+		/* Chars a, e and f have various special meanings apart from
+		   their hex value.  They are handled separately, see below. */
+		case 'b':
+		case 'B':
+		case 'c':
+		case 'C':
+		case 'd':
+		case 'D':
+		  if ((flags & HEXFLT) && nancount + infcount == 0)
+		    {
+		      flags &= ~(SIGNOK | NDIGITS);
+		      goto fok;
+		    }
+		  break;
+
+		case 'x':
+		case 'X':
+		  /* Did we have exactly one leading zero yet? */
+		  if ((flags & (SIGNOK | NDIGITS | HEXFLT)) == NDIGITS
+		      && zeroes == 1)
+		    {
+		      flags |= HEXFLT;
+                      flags &= ~NDIGITS;
+		      /* We skipped the first zero, so we have to add
+			 it now to the buffer. */
+		      *p++ = '0';
+		      width--;
+		      zeroes = 0;
+		      goto fok;
+		    }
+		  break;
+
 		case '+':
 		case '-':
 		  if (flags & SIGNOK)
@@ -1635,6 +1671,11 @@ __SVFSCANF_R (struct _reent *rptr,
 		  break;
 		case 'a':
 		case 'A':
+		  if ((flags & HEXFLT) && nancount + infcount == 0)
+		    {
+		      flags &= ~(SIGNOK | NDIGITS);
+		      goto fok;
+		    }
 		  if (nancount == 1)
 		    {
 		      nancount = 2;
@@ -1659,6 +1700,11 @@ __SVFSCANF_R (struct _reent *rptr,
 		  break;
 		case 'f':
 		case 'F':
+		  if ((flags & HEXFLT) && nancount + infcount == 0)
+		    {
+		      flags &= ~(SIGNOK | NDIGITS);
+		      goto fok;
+		    }
 		  if (infcount == 2)
 		    {
 		      infcount = 3;
@@ -1681,8 +1727,27 @@ __SVFSCANF_R (struct _reent *rptr,
 		      goto fok;
 		    }
 		  break;
+
+		case 'p':
+		case 'P':
+		  /* p is the exponent marker in hex case. */
+		  if (!(flags & HEXFLT))
+		    break;
+		  goto fexp;
 		case 'e':
 		case 'E':
+		  /* e is just a digit in hex case, not the exponent marker. */
+		  if (flags & HEXFLT)
+		    {
+		      if (nancount + infcount == 0)
+			{
+			  flags &= ~(SIGNOK | NDIGITS);
+			  goto fok;
+			}
+		      break;
+		    }
+
+		fexp:
 		  /* no exponent without some digits */
 		  if ((flags & (NDIGITS | EXPOK)) == EXPOK
 		      || ((flags & EXPOK) && zeroes))
@@ -1693,7 +1758,7 @@ __SVFSCANF_R (struct _reent *rptr,
 			  exp_start = p;
 			}
 		      flags =
-			(flags & ~(EXPOK | DPTOK)) |
+			(flags & ~(EXPOK | DPTOK | HEXFLT)) |
 			SIGNOK | NDIGITS;
 		      zeroes = 0;
 		      goto fok;
