@@ -1595,7 +1595,7 @@ wcvt(struct _reent *data, _PRINTF_FLOAT_TYPE value, int ndigits, int flags,
 			value -= mode;
 			*bp++ = digits[mode];
 		} while (ndigits-- && value);
-		if (value > 0.5 || (value == 0.5 && mode & 1)) {
+		if (value > (_PRINTF_FLOAT_TYPE) 0.5 || (value == (_PRINTF_FLOAT_TYPE) 0.5 && mode & 1)) {
 			/* round to even */
 			rve = bp;
 			while (*--rve == digits[0xf]) {
