@@ -32,6 +32,7 @@
  * Interface documentation refer to malloc.c.
  */
 
+#define _DEFAULT_SOURCE
 #include <stdio.h>
 #include <string.h>
 #include <stdbool.h>
@@ -39,14 +40,16 @@
 #include <malloc.h>
 #include <unistd.h>
 #include <sys/config.h>
+#include <sys/lock.h>
 
 #if MALLOC_DEBUG
 #include <assert.h>
-#define MALLOC_LOCK do { __malloc_lock(); __malloc_validate(); } while(0)
-#define MALLOC_UNLOCK do { __malloc_validate(); __malloc_unlock(); } while(0)
+#define MALLOC_LOCK do { __LIBC_LOCK(); __malloc_validate(); } while(0)
+#define MALLOC_UNLOCK do { __malloc_validate(); __LIBC_UNLOCK(); } while(0)
 #else
-#define MALLOC_LOCK __malloc_lock()
-#define MALLOC_UNLOCK __malloc_unlock()
+#define MALLOC_LOCK __LIBC_LOCK()
+#define MALLOC_UNLOCK __LIBC_UNLOCK()
+#undef assert
 #define assert(x) ((void)0)
 #endif
 
@@ -143,8 +146,8 @@ bool __malloc_grow_chunk(chunk_t *c, size_t new_size);
  * call to free.
  */
 #ifdef HAVE_ALIAS_ATTRIBUTE
-extern typeof(free) __malloc_free;
-extern typeof(malloc) __malloc_malloc;
+extern __typeof(free) __malloc_free;
+extern __typeof(malloc) __malloc_malloc;
 #else
 #define __malloc_free(x) free(x)
 #define __malloc_malloc(x) malloc(x)
@@ -224,15 +227,12 @@ void* __malloc_sbrk_aligned(size_t s)
 {
     char *p, *align_p;
 
-    if (__malloc_sbrk_start == NULL)
-	__malloc_sbrk_start = sbrk(0);
-
 #ifdef __APPLE__
     /* Mac OS X 'emulates' sbrk, but the
      * parameter is int, not intptr_t or ptrdiff_t,
      */
     int d = (int) s;
-    if (d != s || d < 0)
+    if (d < 0 || (size_t) d != s)
 	return (void *)-1;
 #else
     ptrdiff_t d = (ptrdiff_t)s;
@@ -268,6 +268,8 @@ void* __malloc_sbrk_aligned(size_t s)
             return (void *) -1;
 	__malloc_sbrk_top = extra + adjust;
     }
+    if (__malloc_sbrk_start == NULL)
+	__malloc_sbrk_start = align_p;
 
     return align_p;
 }
@@ -761,6 +763,8 @@ __strong_reference(memalign, aligned_alloc);
 #ifdef DEFINE_MALLOPT
 int mallopt(int parameter_number, int parameter_value)
 {
+    (void) parameter_number;
+    (void) parameter_value;
     return 0;
 }
 #endif /* DEFINE_MALLOPT */
