@@ -29,6 +29,7 @@ THIS SOFTWARE.
 /* Please send bug reports to David M. Gay (dmg at acm dot org,
  * with " at " changed at "@" and " dot " changed to ".").	*/
 
+#define _DEFAULT_SOURCE
 #include <_ansi.h>
 #include <errno.h>
 #include <stdlib.h>
@@ -460,11 +461,11 @@ _strtodg_l (const char *s00, char **se, FPI *fpi, Long *exp,
 	for(s = s00;;s++) switch(*s) {
 		case '-':
 			sign = 1;
-			/* no break */
+                        FALLTHROUGH;
 		case '+':
 			if (*++s)
 				goto break2;
-			/* no break */
+                        FALLTHROUGH;
 		case 0:
 			sign = 0;
 			irv = STRTOG_NoNumber;
@@ -562,6 +563,7 @@ _strtodg_l (const char *s00, char **se, FPI *fpi, Long *exp,
 		switch(c = *++s) {
 			case '-':
 				esign = 1;
+                                FALLTHROUGH;
 			case '+':
 				c = *++s;
 			}
