@@ -152,8 +152,8 @@ _strtoull_l (const char *__restrict nptr,
 	}
 	if (base == 0)
 		base = c == '0' ? 8 : 10;
-	cutoff = (unsigned long long)ULONG_LONG_MAX / (unsigned long long)base;
-	cutlim = (unsigned long long)ULONG_LONG_MAX % (unsigned long long)base;
+	cutoff = (unsigned long long)ULLONG_MAX / (unsigned long long)base;
+	cutlim = (unsigned long long)ULLONG_MAX % (unsigned long long)base;
 	for (acc = 0, any = 0;; c = *s++) {
 		if (c >= '0' && c <= '9')
 			c -= '0';
@@ -174,7 +174,7 @@ _strtoull_l (const char *__restrict nptr,
 		}
 	}
 	if (any < 0) {
-		acc = ULONG_LONG_MAX;
+		acc = ULLONG_MAX;
 		__errno_r(rptr) = ERANGE;
 	} else if (neg)
 		acc = -acc;
