@@ -1,6 +1,6 @@
 /* Copyright (c) 2005 Jeff Johnston <jjohnstn@redhat.com> */
 #include <sys/types.h>
-#include <local.h>
+#include "local.h"
 
 /* Shared timezone information for libc/time functions.  */
 static __tzinfo_type tzinfo = {1, 0,
