@@ -303,4 +303,4 @@
 {32, 0, 33,__LINE__, 0x7ff80000, 0x00000000, 0x403d7fff, 0xfffffffc},	/* nan=f(29.5)*/
 {0}
 };
-void test_asinf(m)   {run_vector_1(m,asinf_vec,(char *)(asinf),"asinf","ff");   }	
+void test_asinf(int m)   {run_vector_1(m,asinf_vec,(char *)(asinf),"asinf","ff");   }	
