@@ -302,4 +302,4 @@
 {63, 0,123,__LINE__, 0x40104fb1, 0x4017a7ca, 0x403d7fff, 0xfffffffc},	/* 4.07782=f(29.5)*/
 {0}
 };
-void test_asinh(m)   {run_vector_1(m,asinh_vec,(char *)(asinh),"asinh","dd");   }	
+void test_asinh(int m)   {run_vector_1(m,asinh_vec,(char *)(asinh),"asinh","dd");   }	
