@@ -47,9 +47,24 @@ test_strtod (void)
   char *tail;
   double v;
   /* On average we'll loose 1/2 a bit, so the test is for within 1 bit  */
+  errno = 0;
   v = strtod(pd->string, &tail);
+  if (tail - pd->string) {
+    if (fabs(v) < DBL_MIN && !(pd->endscan & ENDSCAN_IS_ZERO)) {
+#ifdef NO_NEWLIB
+      /* Glibc has bugs in strtod with hex format float */
+      if (strncasecmp(pd->string, "0x", 2) == 0)
+        ;
+      else
+#endif
+        test_eok(errno, ERANGE);
+    } else if (v == (double) INFINITY && !(pd->endscan & ENDSCAN_IS_INF))
+      test_eok(errno, ERANGE);
+    else
+      test_eok(errno, 0);
+  }
   test_mok(v, pd->value, CONVERT_BITS_DOUBLE);
-  test_iok(tail - pd->string, pd->endscan);
+  test_iok(tail - pd->string, pd->endscan & ENDSCAN_MASK);
 }
 
 void
@@ -58,9 +73,19 @@ test_strtof (void)
   char *tail;
   float v;
   /* On average we'll loose 1/2 a bit, so the test is for within 1 bit  */
+  errno = 0;
   v = strtof(pd->string, &tail);
-  test_mok((double) v, pd->value, CONVERT_BITS_FLOAT);
-  test_iok(tail - pd->string, pd->endscan);
+  if (tail - pd->string) {
+    int e = errno;
+    if (fabsf(v) < FLT_MIN && !(pd->endscan & ENDSCAN_IS_ZERO))
+      test_eok(e, ERANGE);
+    else if (v == INFINITY && !(pd->endscan & ENDSCAN_IS_INF))
+      test_eok(errno, ERANGE);
+    else
+      test_eok(errno, 0);
+  }
+  test_mfok((double) v, pd->value, CONVERT_BITS_FLOAT);
+  test_iok(tail - pd->string, pd->endscan & ENDSCAN_MASK);
 }
 
 #if defined(_HAVE_LONG_DOUBLE) && (__LDBL_MANT_DIG__ == 64 || defined(TINY_STDIO))
@@ -72,11 +97,24 @@ void
 test_strtold (void)
 {
   char *tail;
-  long double v;
+  long double v, av;
   /* On average we'll loose 1/2 a bit, so the test is for within 1 bit  */
+  errno = 0;
   v = strtold(pd->string, &tail);
+  if (tail - pd->string) {
+    int e = errno;
+    av = v;
+    if (av < 0)
+      av = -av;
+    if (av < LDBL_MIN && !(pd->endscan & ENDSCAN_IS_ZERO))
+      test_eok(e, ERANGE);
+    else if (v == (long double) INFINITY && !(pd->endscan & ENDSCAN_IS_INF))
+      test_eok(e, ERANGE);
+    else
+      test_eok(e, 0);
+  }
   test_mok(v, pd->value, CONVERT_BITS_DOUBLE);
-  test_iok(tail - pd->string, pd->endscan);
+  test_iok(tail - pd->string, pd->endscan & ENDSCAN_MASK);
 }
 #endif
 
@@ -91,13 +129,13 @@ void
 test_atoff (void)
 {
   float v = atoff(pd->string);
-  test_mok((double) v, pd->value, 30);
+  test_mfok(v, (float) pd->value, CONVERT_BITS_FLOAT);
 }
 #endif
 
 
 static
-void 
+void
 iterate (void (*func) (void),
        char *name)
 {
@@ -234,9 +272,9 @@ test_gcvt (void)
 {
   char *s = check_null(gcvt(pdd->value, pdd->g1, buffer));
   test_scok(s, pdd->gstring, 9);
-  
+
 #ifndef NO_NEWLIB
-  s = check_null(gcvtf(pdd->value, pdd->g1, buffer)); 
+  s = check_null(gcvtf(pdd->value, pdd->g1, buffer));
   test_scok2(s, pdd->gstring, pdd->gfstring, 6);
 #endif
 }
@@ -260,6 +298,7 @@ test_fcvt (void)
   /* Test the float version by converting and inspecting the numbers 3
    after reconverting */
   sf =  check_null(fcvtf(pdd->value, pdd->f1, &a2, &a3));
+  errno = 0;
   v1 = strtod(sd, &sde);
   v2 = strtod(sf, &sfe);
   /* float version may return fewer digits; expand to match */
@@ -317,13 +356,13 @@ deltest (void)
   line(5);
   sprintf(buffer,"%.0e",1e1);
   test_sok(buffer,"1e+01");
-  line(6);  
+  line(6);
   sprintf(buffer, "%f", 12.3456789);
   test_sok(buffer, "12.345679");
-  line(7);  
+  line(7);
   sprintf(buffer, "%6.3f", 12.3456789);
   test_sok(buffer, "12.346");
-  line(8);  
+  line(8);
   sprintf(buffer,"%.0f", 12.3456789);
   test_sok(buffer,"12");
 #endif
@@ -342,11 +381,11 @@ test_sprint (void)
   sprint_int_type *si = sprint_ints;
 
 
-  newfunc( "sprintf");  
+  newfunc( "sprintf");
 
 
 #if defined(TINY_STDIO) || !defined(NO_FLOATING_POINT)
-  while (s->line) 
+  while (s->line)
   {
     line( s->line);
     sprintf(buffer, s->format_string, s->value);
@@ -365,7 +404,7 @@ test_sprint (void)
   }
 #endif
 
-  while (si->line) 
+  while (si->line)
   {
     line( si->line);
     if (strchr(si->format_string, 'l'))
@@ -383,7 +422,7 @@ test_sprint (void)
     test_sok(buffer, si->result);
 #endif
     si++;
-  }  
+  }
 }
 
 /* Scanf calls strtod etc tested elsewhere, but also has some pattern matching skills */
@@ -398,13 +437,13 @@ test_scan (void)
   extern sprint_int_type sprint_ints[];
   sprint_int_type *si = sprint_ints;
 
-  newfunc( "scanf");  
-  
+  newfunc( "scanf");
+
 #if defined(TINY_STDIO) || !defined(NO_FLOATING_POINT)
   /* Test scanf by converting all the numbers in the sprint vectors
      to and from their source and making sure nothing breaks */
 
-  while (s->line) 
+  while (s->line)
   {
 
     double d0,d1;
@@ -421,11 +460,11 @@ test_scan (void)
 #endif
 
   /* And integers too */
-  while (si->line) 
+  while (si->line)
   {
 
     long d0,d1;
-    
+
     line(si->line);
     sscanf(si->result, "%ld", &d0);
     sprintf(buffer, "%ld", d0);
@@ -441,7 +480,7 @@ test_scan (void)
   sscanf("foo bar 123 zap 456","foo bar %d zap %d", &i, &j);
   test_iok(i, 123);
   test_iok(j, 456);
-  
+
   sscanf("magicXYZZYfoobar","magic%[XYZ]", buffer);
   test_sok("XYZZY", buffer);
   sscanf("magicXYZZYfoobar","%[^XYZ]", buffer);
@@ -497,7 +536,7 @@ test_cvt (void)
 #endif
 
   test_scan();
-  test_sprint();  
+  test_sprint();
   iterate(test_atof, "atof");
 #ifndef NO_NEWLIB
   iterate(test_atoff, "atoff");
