@@ -300,5 +300,5 @@
 {64, 0,123,__LINE__, 0x40146f6d, 0x70171f62, 0x403a1999, 0x99999996},	/* 5.10882=f(26.1)*/
 {63, 0,123,__LINE__, 0x4015171c, 0xbaaadfe1, 0x403bcccc, 0xccccccc9},	/* 5.27257=f(27.8)*/
 {63, 0,123,__LINE__, 0x4015b9be, 0x5d52a9d9, 0x403d7fff, 0xfffffffc},	/* 5.43139=f(29.5)*/
-0,};
-void test_sqrt(m)   {run_vector_1(m,sqrt_vec,(char *)(sqrt),"sqrt","dd");   }	
+{0},};
+void test_sqrt(int m)   {run_vector_1(m,sqrt_vec,(char *)(sqrt),"sqrt","dd");   }	
