@@ -14,6 +14,7 @@
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
+#define _GNU_SOURCE
 #define HAVE_FLOAT 1
 #define X(x) (char *)x
 
@@ -210,7 +211,7 @@ int fmag_of_error (float, float);
 #define VECCLOSE(f,name,args)\
 {\
   fprintf(f,"0,};\n");      \
-   fprintf(f,"test_%s(m)   {run_vector_1(m,%s_vec,(char *)(%s),\"%s\",\"%s\");   }	\n",\
+   fprintf(f,"test_%s(int m)   {run_vector_1(m,%s_vec,(char *)(%s),\"%s\",\"%s\");   }	\n",\
 	   name,\
 	   name,name,name,args);\
 	    fclose(f);\
@@ -227,6 +228,9 @@ typedef struct
   int endscan;
 } double_type;
 
+#define ENDSCAN_MASK	0x7f
+#define ENDSCAN_IS_ZERO	0x80
+#define ENDSCAN_IS_INF	0x80
 
 typedef struct {
   long int value;
@@ -292,6 +296,7 @@ void test_cvt (void);
 void line (int);
 
 void test_mok (double, double, int);
+void test_mfok (float, float, int);
 void test_iok (int, int);
 void test_eok (int, int);
 void test_sok (char *, char*);
@@ -476,6 +481,12 @@ test_pow_vec(int vector);
 void
 test_powf_vec(int vector);
 
+void
+test_scalbn(int vector);
+
+void
+test_scalbnf(int vector);
+
 void
 test_sin(int vector);
 
